@@ -10,9 +10,6 @@ use crate::*;
 
 use super::*;
 
-#[derive(Default)]
-pub struct RequestParser {}
-
 const MAX_ADDRESS_LEN: usize = 256;
 const MAX_DOMAIN_LEN: usize = 255;
 
@@ -431,7 +428,7 @@ impl<'x, 'y> Rfc5321Parser<'x, 'y> {
                 b'>' if !in_quote => {
                     self.stop_char = ch;
                     let value = value.into_string();
-                    let len = value.chars().count();
+                    let len = value.len();
                     return Ok(
                         if len == 0 || len <= MAX_ADDRESS_LEN && at_count == 1 && lp_len > 0 {
                             value.into()
@@ -452,7 +449,7 @@ impl<'x, 'y> Rfc5321Parser<'x, 'y> {
                     if !value.is_empty() {
                         self.stop_char = b' ';
                         let value = value.into_string();
-                        let len = value.chars().count();
+                        let len = value.len();
                         return Ok(
                             if len == 0 || len <= MAX_ADDRESS_LEN && at_count == 1 && lp_len > 0 {
                                 value.into()
@@ -465,7 +462,7 @@ impl<'x, 'y> Rfc5321Parser<'x, 'y> {
                 b'\n' => {
                     self.stop_char = b'\n';
                     let value = value.into_string();
-                    let len = value.chars().count();
+                    let len = value.len();
                     return Ok(
                         if len == 0 || len <= MAX_ADDRESS_LEN && at_count == 1 && lp_len > 0 {
                             value.into()
@@ -1759,7 +1756,7 @@ mod tests {
                 Err(Error::InvalidParameter { param: "HOLDFOR" }),
             ),
             (
-                concat!("RCPT TO:<> NOTIFY=FAILURE"),
+                "RCPT TO:<> NOTIFY=FAILURE",
                 Ok(Request::Rcpt {
                     to: RcptTo {
                         address: "".to_string(),
@@ -1769,7 +1766,7 @@ mod tests {
                 }),
             ),
             (
-                concat!("RCPT TO:<> NOTIFY=FAILURE,DELAY"),
+                "RCPT TO:<> NOTIFY=FAILURE,DELAY",
                 Ok(Request::Rcpt {
                     to: RcptTo {
                         address: "".to_string(),
@@ -1779,7 +1776,7 @@ mod tests {
                 }),
             ),
             (
-                concat!("RCPT TO:<> NOTIFY=SUCCESS,FAILURE,DELAY"),
+                "RCPT TO:<> NOTIFY=SUCCESS,FAILURE,DELAY",
                 Ok(Request::Rcpt {
                     to: RcptTo {
                         address: "".to_string(),
@@ -1789,7 +1786,7 @@ mod tests {
                 }),
             ),
             (
-                concat!("RCPT TO:<> NOTIFY=NEVER"),
+                "RCPT TO:<> NOTIFY=NEVER",
                 Ok(Request::Rcpt {
                     to: RcptTo {
                         address: "".to_string(),
@@ -1811,7 +1808,7 @@ mod tests {
                 Err(Error::InvalidParameter { param: "NOTIFY" }),
             ),
             (
-                concat!("RCPT TO:<> ORCPT=rfc822;Bob@Example.COM"),
+                "RCPT TO:<> ORCPT=rfc822;Bob@Example.COM",
                 Ok(Request::Rcpt {
                     to: RcptTo {
                         address: "".to_string(),
@@ -1889,7 +1886,7 @@ mod tests {
                 Err(Error::InvalidParameter { param: "ENVID" }),
             ),
             (
-                concat!("MAIL FROM:<> SOLICIT=org.example:ADV:ADLT",),
+                "MAIL FROM:<> SOLICIT=org.example:ADV:ADLT",
                 Ok(Request::Mail {
                     from: MailFrom {
                         address: "".to_string(),
@@ -2040,7 +2037,7 @@ mod tests {
                 }),
             ),
             (
-                concat!("RCPT TO:<> RRVS=2014-04-03T23:01:00Z"),
+                "RCPT TO:<> RRVS=2014-04-03T23:01:00Z",
                 Ok(Request::Rcpt {
                     to: RcptTo {
                         address: "".to_string(),
@@ -2051,7 +2048,7 @@ mod tests {
                 }),
             ),
             (
-                concat!("RCPT TO:<> RRVS=1997-11-24T14:22:01-08:00;C"),
+                "RCPT TO:<> RRVS=1997-11-24T14:22:01-08:00;C",
                 Ok(Request::Rcpt {
                     to: RcptTo {
                         address: "".to_string(),
@@ -2062,7 +2059,7 @@ mod tests {
                 }),
             ),
             (
-                concat!("RCPT TO:<> RRVS=2003-07-01T10:52:37+02:00;R"),
+                "RCPT TO:<> RRVS=2003-07-01T10:52:37+02:00;R",
                 Ok(Request::Rcpt {
                     to: RcptTo {
                         address: "".to_string(),
